<?php
/**
 * Gutenberg theme support.
 *
 * @package Aspire
 * @author  Appfinite
 * @license GPL-2.0-or-later
 * @link    https://www.appfinite.com/
 */

 add_action( 'wp_enqueue_scripts', 'aspire_enqueue_gutenberg_frontend_styles' );
 /**
  * Enqueues Gutenberg front-end styles.
  *
  * @since 2.7.0
  */
 function aspire_enqueue_gutenberg_frontend_styles() {

 	$child_theme_slug = defined( 'CHILD_THEME_NAME' ) && CHILD_THEME_NAME ? sanitize_title_with_dashes( CHILD_THEME_NAME ) : 'aspire';

 	wp_enqueue_style(
 		'aspire-gutenberg',
 		get_stylesheet_directory_uri() . '/lib/gutenberg/front-end.css',
 		array( $child_theme_slug ),
 		CHILD_THEME_VERSION
 	);

 }

 add_action( 'enqueue_block_editor_assets', 'aspire_block_editor_styles' );
 /**
  * Enqueues Gutenberg admin editor fonts and styles.
  *
  * @since 2.7.0
  */
 function aspire_block_editor_styles() {

 	wp_enqueue_style(
 		'aspire-gutenberg-fonts',
 		'https://fonts.googleapis.com/css?family=Source+Sans+Pro:400,400i,600,700',
 		array(),
 		CHILD_THEME_VERSION
 	);

 }

 add_filter( 'body_class', 'aspire_blocks_body_classes' );
/**
 * Adds body classes to help with block styling.
 *
 * - `has-no-blocks` if content contains no blocks.
 * - `first-block-[block-name]` to allow changes based on the first block (such as removing padding above a Cover block).
 * - `first-block-align-[alignment]` to allow styling adjustment if the first block is wide or full-width.
 *
 * @since 2.8.0
 *
 * @param array $classes The original classes.
 * @return array The modified classes.
 */
function aspire_blocks_body_classes( $classes ) {

	if ( ! is_singular() || ! function_exists( 'has_blocks' ) || ! function_exists( 'parse_blocks') ) {
		return $classes;
	}

	if ( ! has_blocks() ) {
		$classes[] = 'has-no-blocks';
		return $classes;
	}

	$post_object = get_post( get_the_ID() );
	$blocks      = (array) parse_blocks( $post_object->post_content );

	if ( isset( $blocks[0]['blockName'] ) ) {
		$classes[] = 'first-block-' . str_replace( '/', '-', $blocks[0]['blockName'] );
	}

	if ( isset( $blocks[0]['attrs']['align'] ) ) {
		$classes[] = 'first-block-align-' . $blocks[0]['attrs']['align'];
	}

	return $classes;

}

 // Add support for editor styles.
 add_theme_support( 'editor-styles' );

 // Enqueue editor styles.
 add_editor_style( '/lib/gutenberg/style-editor.css' );

 // Adds support for block alignments.
 add_theme_support( 'align-wide' );

 // Make media embeds responsive.
 add_theme_support( 'responsive-embeds' );

 // Adds support for editor font sizes.
 add_theme_support(
 	'editor-font-sizes',
 	array(
 		array(
 			'name'      => __( 'Small', 'aspire' ),
 			'shortName' => __( 'S', 'aspire' ),
 			'size'      => 12,
 			'slug'      => 'small',
 		),
 		array(
 			'name'      => __( 'Normal', 'aspire' ),
 			'shortName' => __( 'M', 'aspire' ),
 			'size'      => 16,
 			'slug'      => 'normal',
 		),
 		array(
 			'name'      => __( 'Large', 'aspire' ),
 			'shortName' => __( 'L', 'aspire' ),
 			'size'      => 20,
 			'slug'      => 'large',
 		),
 		array(
 			'name'      => __( 'Larger', 'aspire' ),
 			'shortName' => __( 'XL', 'aspire' ),
 			'size'      => 24,
 			'slug'      => 'larger',
 		),
 	)
 );

 // Adds support for editor color palette.
 add_theme_support(
 	'editor-color-palette',
 	array(
 		array(
 			'name'  => __( 'Light gray', 'aspire' ),
 			'slug'  => 'light-gray',
 			'color' => '#f5f5f5',
 		),
 		array(
 			'name'  => __( 'Medium gray', 'aspire' ),
 			'slug'  => 'medium-gray',
 			'color' => '#999',
 		),
 		array(
 			'name'  => __( 'Dark gray', 'aspire' ),
 			'slug'  => 'dark-gray',
 			'color' => '#333',
 		),
 	)
 );

 add_action( 'after_setup_theme', 'aspire_content_width', 0 );
 /**
  * Set content width to match the “wide” Gutenberg block width.
  */
 function aspire_content_width() {

 	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound -- See https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/924
 	$GLOBALS['content_width'] = apply_filters( 'aspire_content_width', 1062 );

 }
